clear 
set more off
cd "X:\Data\Matlab\Fogli and Veldkamp Replication"
use "PANEL_ECMA.dta", clear

set more off
gen yearnew=(year==1940)
recode yearnew 0=2 if year==1950
recode yearnew 0=3 if year==1960
recode yearnew 0=4 if year==1970
recode yearnew 0=5 if year==1980
recode yearnew 0=6 if year==1990
recode yearnew 0=7 if year==2000

xtset fips yearnew, yearly

tabulate yearnew, gen(yeardum)
 
gen densitynew=density/1000
drop density
rename densitynew density
gen LFP_lag=l.LFP
gen LFP_spaw2_lag=l.LFP_spaw2

bysort fips: egen m_LFP = mean(LFP)
bysort fips: egen m_LFP_lag = mean(LFP_lag)
bysort fips: egen m_LFP_spaw2_lag = mean(LFP_spaw2_lag)
bysort fips: egen m_density = mean(density)
bysort fips: egen m_pc_urb = mean(pc_urb)
bysort fips: egen m_pc_farm = mean(pc_farm)
bysort fips: egen m_avg_edu = mean(avg_edu)
bysort fips: egen m_avgwage_defl = mean(avgwage_defl)

gen dm_LFP = LFP - m_LFP
gen dm_LFP_lag = LFP_lag - m_LFP_lag
gen dm_LFP_spaw2_lag = LFP_spaw2_lag - m_LFP_spaw2_lag
gen dm_density = density - m_density
gen dm_pc_urb = pc_urb - m_pc_urb
gen dm_pc_farm = pc_farm - m_pc_farm
gen dm_avg_edu = avg_edu - m_avg_edu
gen dm_avgwage_defl = avgwage_defl - m_avgwage_defl



bysort fips: gen LFP_diff = LFP-l.LFP
bysort fips: gen LFP_lag_diff =l.LFP_diff
bysort fips: gen LFP_lag2_diff=ll.LFP_diff
bysort fips: gen LFP_spaw2_diff =LFP_spaw2-l.LFP_spaw2
bysort fips: gen LFP_spaw2_lag_diff=l.LFP_spaw2_diff
bysort fips: gen LFP_spaw2_lag2_diff=ll.LFP_spaw2_diff
bysort fips: gen density_diff = density-l.density
bysort fips: gen pc_urb_diff = pc_urb-l.pc_urb
bysort fips: gen pc_farm_diff = pc_farm-l.pc_farm
bysort fips: gen avg_edu_diff = avg_edu-l.avg_edu
bysort fips: gen avgwage_defl_diff =avgwage_defl-l.avgwage_defl

bysort fips: egen m_LFP_diff = mean(LFP_diff)
bysort fips: egen m_LFP_lag_diff = mean(LFP_lag_diff)
bysort fips: egen m_LFP_spaw2_lag_diff = mean(LFP_spaw2_lag_diff)

bysort fips: egen m_LFP_lag2_diff = mean(LFP_lag2_diff)
bysort fips: egen m_LFP_spaw2_lag2_diff = mean(LFP_spaw2_lag2_diff)


bysort fips: egen m_density_diff = mean(density_diff)
bysort fips: egen m_pc_urb_diff = mean(pc_urb_diff)
bysort fips: egen m_pc_farm_diff = mean(pc_farm_diff)
bysort fips: egen m_avg_edu_diff = mean(avg_edu_diff)
bysort fips: egen m_avgwage_defl_diff = mean(avgwage_defl_diff)


gen dm_LFP_diff = LFP_diff - m_LFP_diff
gen dm_LFP_lag_diff = LFP_lag_diff - m_LFP_lag_diff
gen dm_LFP_spaw2_lag_diff = LFP_spaw2_lag_diff - m_LFP_spaw2_lag_diff
gen dm_LFP_lag2_diff=LFP_spaw2_lag2_diff - m_LFP_spaw2_lag2_diff
gen dm_LFP_spaw2_lag2_diff=LFP_lag2_diff - m_LFP_lag2_diff
gen dm_density_diff = density_diff - m_density_diff
gen dm_pc_urb_diff = pc_urb_diff - m_pc_urb_diff
gen dm_pc_farm_diff = pc_farm_diff - m_pc_farm_diff
gen dm_avg_edu_diff = avg_edu_diff - m_avg_edu_diff
gen dm_avgwage_defl_diff = avgwage_defl_diff - m_avgwage_defl_diff


gen avgwage_defl2=avgwage_defl/10000
drop avgwage_defl
rename avgwage_defl2 avgwage_defl
**OLS LEVELS (1)
xtreg LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, robust cluster(fips) // This is random effects
//outreg2 using "Regression_results.xls", excel replace dec(3)

**OLS LEVELS
//reg LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, robust cluster(fips)
//estimates store ols_lev
//abar,lags(2)

**OLS LEVELS FIXED EFFECTS
//xtreg LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, fe robust cluster(fips)
//estimates store ols_lev_fe

//reg dm_LFP dm_LFP_lag dm_LFP_spaw2_lag dm_density dm_pc_urb dm_pc_farm dm_avg_edu dm_avgwage_defl yeardum*, robust cluster(fips)
//abar,lags(2)


**IV FIRST DIFFERENCES

//ivreg2 d.LFP (ld.LFP ld.LFP_spaw2=lld.LFP lld.LFP_spaw2)d.density d.pc_urb d.pc_farm d.avg_edu d.avgwage_defl yeardum*, robust cluster(fips)
//estimates store IV_fd
//abar,lags(2)

**IV first differences and fixed effects (2)
//xtivreg2 d.LFP (ld.LFP ld.LFP_spaw2=lld.LFP lld.LFP_spaw2) d.density d.pc_urb d.pc_farm d.avg_edu d.avgwage_defl yeardum*, fe robust cluster(fips) // This is the Anderson and Hsiao (1981) IV estimator according to the reviewer
//estimates store IV_fd_fe
//outreg2 using "Regression_results.xls", excel append dec(3)

//ivreg2 dm_LFP_diff (dm_LFP_lag_diff dm_LFP_spaw2_lag_diff=dm_LFP_lag2_diff dm_LFP_spaw2_lag2_diff) dm_density_diff dm_pc_urb_diff dm_pc_farm_diff dm_avg_edu_diff dm_avgwage_defl_diff yeardum*,robust cluster(fips)
//abar,lags(2)

**A-B GMM--two lags (3)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum4-yeardum7 , gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(2 3)collapse)  iv(yeardum4-yeardum7 density pc_urb pc_farm avg_edu,passthru) nol r  two
//outreg2 using "Regression_results.xls", excel append dec(3)
//estimates store AB_2ls

**A-B GMM more lags (4)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum4-yeardum7 , gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(2 4)collapse)  iv(yeardum4-yeardum7 density pc_urb pc_farm avg_edu,passthru) nol r  two
//outreg2 using "Regression_results.xls", excel append dec(3)
//estimates store AB_3ls

//estimates table ols_lev_fe IV_fd IV_fd_fe AB_2ls AB_3ls, drop(yeardum1 yeardum2 yeardum3 yeardum4 yeardum5 yeardum6 yeardum7 _cons )b(%7.3f) se(%7.3f) stfmt(%7.4g) stats(N r2_a)

****************************************************************************************************************************************************************************************************
// NEW (5,6,9 are preferred models)
** OLS with fixed effects, FV (2011) claim to use fixed effects but they actually report the results of the random effects model (5)
xtreg LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, fe robust cluster(fips) 
//outreg2 using "Regression_results.xls", excel append dec(3)

** This uses is the Anderson and Hsiao (1981) IV estimator which instruments the second lag of the LFP rate and its spatial lag for the lagged difference of the LFP rate and its spatial lag. Note this is what FV suggest to do but they take the the second lag of the differenced LFP rate and its spatial lag as instruments. (6)
//xtivreg2 d.LFP (ld.LFP ld.LFP_spaw2=ll.LFP ll.LFP_spaw2) d.density d.pc_urb d.pc_farm d.avg_edu d.avgwage_defl yeardum*, fe robust cluster(fips) 
//outreg2 using "Regression_results.xls", excel append dec(3)

**A-B GMM--two lags (corrected lags, all time dummies) (7)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(1 2)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu,passthru) nol r  two
//outreg2 using "Replication\Regression_results.xls", excel append dec(3)

**A-B GMM three lags (corrected lags, all time dummies) (8)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(1 3)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu,passthru) nol r two
//outreg2 using "Regression_results.xls", excel append dec(3)

**A-B GMM three lags (corrected lags, all time dummies, no collapse)
//xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(1 3))  iv(yeardum* density pc_urb pc_farm avg_edu,passthru) nol r two
//outreg2 using "C:\Users\ioann\Documents\Replication\Regression_results.xls", excel append dec(3)

**A-B GMM three lags (corrected lags, all time dummies, wages treated as exogenous) (9)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu avgwage_defl,passthru) nol r two
//outreg2 using "Regression_results.xls", excel append dec(3)

**A-B GMM three lags (corrected lags, all time dummies, no wages in the model) (10)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu,passthru) nol r two
//outreg2 using "Regression_results.xls", excel append dec(3)

**A-B GMM three lags (corrected lags, all time dummies, wages treated as exogenous, differenced x variables as instruments) 
//xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* d.density d.pc_urb d.pc_farm d.avg_edu d.avgwage_defl,passthru) nol r two
//outreg2 using "C:\Users\ioanna\Documents\Replication\Regression_results.xls", excel append dec(3)

**A-B GMM three lags (corrected lags, all time dummies, differenced x variables as instruments, no wages) (11)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* d.density d.pc_urb d.pc_farm d.avg_edu,passthru) nol r two
//outreg2 using "Regression_results.xls", excel append dec(3)

**A-B GMM three lags (corrected lags, all time dummies, wages treated as exogenous, x variables different time periods as instruments)
//xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* l.density l2.density l3.density density f.density f1.density f2.density f3.density l.pc_urb l2.pc_urb l3.pc_urb pc_urb f.pc_urb f1.pc_urb f2.pc_urb f3.pc_urb l.pc_farm l2.pc_farm l3.pc_farm pc_farm f.pc_farm f1.pc_farm f2.pc_farm f3.pc_farm l.avg_edu l2.avg_edu l3.avg_edu avg_edu f.avg_edu f1.avg_edu f2.avg_edu f3.avg_edu l.avgwage_defl l2.avgwage_defl l3.avgwage_defl avgwage_defl f.avgwage_defl f1.avgwage_defl f2.avgwage_defl f3.avgwage_defl,passthru) nol r two
//outreg2 using "C:\Users\ioanna\Documents\Replication\Regression_results.xls", excel append dec(3)

