clear 
set more off

use "E:\Documents\Replication\Fogli and Veldkamp Codes\Data\PANEL_ECMA.dta", clear
log using "E:\Documents\Replication\Replication_LOG.smcl", replace

set more off
gen yearnew=(year==1940)
recode yearnew 0=2 if year==1950
recode yearnew 0=3 if year==1960
recode yearnew 0=4 if year==1970
recode yearnew 0=5 if year==1980
recode yearnew 0=6 if year==1990
recode yearnew 0=7 if year==2000

xtset fips yearnew, yearly

tabulate yearnew, gen(yeardum)
 
gen densitynew=density/1000
drop density
rename densitynew density
gen LFP_lag=l.LFP
gen LFP_spaw2_lag=l.LFP_spaw2

gen avgwage_defl2=avgwage_defl/10000
drop avgwage_defl
rename avgwage_defl2 avgwage_defl

**OLS LEVELS (1)
xtreg LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, robust cluster(fips) // This is random effects

**IV FIRST DIFFERENCES

**IV first differences and fixed effects (2)
xtivreg2 d.LFP (ld.LFP ld.LFP_spaw2=lld.LFP lld.LFP_spaw2) d.density d.pc_urb d.pc_farm d.avg_edu d.avgwage_defl yeardum*, fe robust cluster(fips) // This is the Anderson and Hsiao (1981) IV estimator according to the authors
//estimates store IV_fd_fe

//ivreg2 dm_LFP_diff (dm_LFP_lag_diff dm_LFP_spaw2_lag_diff=dm_LFP_lag2_diff dm_LFP_spaw2_lag2_diff) dm_density_diff dm_pc_urb_diff dm_pc_farm_diff dm_avg_edu_diff dm_avgwage_defl_diff yeardum*,robust cluster(fips)
//abar,lags(2)

**A-B GMM--two lags (3)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum4-yeardum7 , gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(2 3)collapse)  iv(yeardum4-yeardum7 density pc_urb pc_farm avg_edu,passthru) nol r  two
//estimates store AB_2ls

**A-B GMM more lags (4)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum4-yeardum7 , gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(2 4)collapse)  iv(yeardum4-yeardum7 density pc_urb pc_farm avg_edu,passthru) nol r  two
//estimates store AB_3ls


****************************************************************************************************************************************************************************************************
// NEW (5,6,9 are preferred models)
** OLS with fixed effects, FV (2011) claim to use fixed effects but they actually report the results of the random effects model (5)
xtreg LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, fe robust cluster(fips) 

** This uses is the Anderson and Hsiao (1981) IV estimator which instruments the second lag of the LFP rate and its spatial lag for the lagged difference of the LFP rate and its spatial lag. Note this is what FV suggest to do but they take the the second lag of the differenced LFP rate and its spatial lag as instruments. (6)
xtivreg2 d.LFP (ld.LFP ld.LFP_spaw2=ll.LFP ll.LFP_spaw2) d.density d.pc_urb d.pc_farm d.avg_edu d.avgwage_defl yeardum*, fe robust cluster(fips) 

**A-B GMM--two lags (corrected lags, all time dummies) (7)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(1 2)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu,passthru) nol r  two
outreg2 using "C:\Users\ioann\Documents\Replication\Regression_results.xls", excel append dec(3)

**A-B GMM three lags (corrected lags, all time dummies) (8)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(1 3)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu,passthru) nol r two

**A-B GMM three lags (corrected lags, all time dummies, wages treated as exogenous) (9)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu avgwage_defl,passthru) nol r two


** Additional estimations, mentioned in footnote 5
**A-B GMM three lags (corrected lags, all time dummies, wages treated as exogenous, differenced x variables as instruments) 
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* d.density d.pc_urb d.pc_farm d.avg_edu d.avgwage_defl,passthru) nol r two

**A-B GMM three lags (corrected lags, all time dummies, no wages in the model) 
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu,passthru) nol r two

**A-B GMM three lags (corrected lags, all time dummies, wages treated as endogenous) 
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2 avgwage_defl, lag(1 3)collapse)  iv(yeardum* density pc_urb pc_farm avg_edu,passthru) nol r two

**A-B GMM three lags (corrected lags, all time dummies, wages treated as exogenous, x variables different time periods as instruments)
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3)collapse)  iv(yeardum* l.density l2.density l3.density density f.density f1.density f2.density f3.density l.pc_urb l2.pc_urb l3.pc_urb pc_urb f.pc_urb f1.pc_urb f2.pc_urb f3.pc_urb l.pc_farm l2.pc_farm l3.pc_farm pc_farm f.pc_farm f1.pc_farm f2.pc_farm f3.pc_farm l.avg_edu l2.avg_edu l3.avg_edu avg_edu f.avg_edu f1.avg_edu f2.avg_edu f3.avg_edu l.avgwage_defl l2.avgwage_defl l3.avgwage_defl avgwage_defl f.avgwage_defl f1.avgwage_defl f2.avgwage_defl f3.avgwage_defl,passthru) nol r two

**A-B GMM three lags (corrected lags, all time dummies, wages treated as exogenous, no collapse) 
xtabond2 LFP l.LFP l.LFP_spaw2 density pc_urb pc_farm avg_edu avgwage_defl yeardum*, gmm(l.LFP l.LFP_spaw2, lag(1 3))  iv(yeardum* density pc_urb pc_farm avg_edu avgwage_defl,passthru) nol r two


log close


